AioScanner class
The main class for interacting with document and barcode scanning functionality.
This class provides methods to check for scanning support on the current platform and to initiate different types of scanning operations (documents and barcodes). It communicates with platform-specific implementations via method channels.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateThumbnail(
String filePath) → Future< Map< String, dynamic> > - Generates a thumbnail for a file (image or PDF)
-
isBarcodeScanningSupported(
) → Future< bool> - Checks if the current platform supports barcode scanning functionality.
-
isDocumentScanningSupported(
) → Future< bool> - Checks if the current platform supports document scanning functionality.
-
startBarcodeScanning(
{List< String> recognizedFormats = const [], String scanningMessage = 'Point camera at a barcode'}) → Future<BarcodeScanResult?> - Starts the barcode scanning process.
-
startDocumentScanning(
{String outputDirectory = 'scanned_documents', int maxNumPages = 5, String initialMessage = 'Position document in frame', String scanningMessage = 'Hold still...', bool allowGalleryImport = true, ScanOutputFormat outputFormat = ScanOutputFormat.image, bool mergePDF = true}) → Future< ScanResult?> - Starts the document scanning process.